# mvc-lib-py

[![build](https://github.com/MetaverseChain/mvc-lib-py/actions/workflows/build.yml/badge.svg)](https://github.com/MetaverseChain/mvc-lib-py/actions/workflows/build.yml)
[![codecov](https://codecov.io/gh/MetaverseChain/mvc-lib-py/branch/master/graph/badge.svg?token=WP5YD1DYRQ)](https://codecov.io/gh/MetaverseChain/mvc-lib-py)
[![PyPI version](https://img.shields.io/pypi/v/mvclib)](https://pypi.org/project/mvclib)
[![Python versions](https://img.shields.io/pypi/pyversions/mvclib)](https://pypi.org/project/mvclib)
[![MIT license](https://img.shields.io/badge/license-MIT-blue)](https://en.wikipedia.org/wiki/MIT_License)

## Installation

```bash
$ pip install mvclib
```
